@@ -1,15 +1,14 @@
 """Sphinx directives."""
 from typing import List, Optional, Tuple
 
-from docutils.nodes import caption, Element, figure, image as docutils_image, legend, reference
+from docutils.nodes import caption, Element, image as docutils_image, legend, reference
 from docutils.parsers.rst.directives import flag, unchanged
-from docutils.parsers.rst.directives.images import Figure
 from sphinx.util import logging as sphinx_logging
 from sphinx.util.docutils import SphinxDirective
 
 from sphinx_carousel import nodes
 
-ImageTuple = Tuple[docutils_image, Optional[reference], Optional[str], Optional[str]]
+ImageTuple = Tuple[docutils_image, Optional[reference], str, str]
 
 
 class Carousel(SphinxDirective):
@@ -59,9 +58,9 @@ class Carousel(SphinxDirective):
             linked_image = image.parent if image.parent.hasattr("refuri") else None
             # Handle captions.
             node = (linked_image or image).next_node(caption, siblings=True, ascend=False, descend=False)
-            title = node.astext() if node else None
+            title = node.astext() if node else ""
             node = (linked_image or image).next_node(legend, siblings=True, ascend=False, descend=False)
-            description = node.astext() if node else None
+            description = node.astext() if node else ""
             # Done with image.
             images.append((image, linked_image, title, description))
 
@@ -129,22 +128,3 @@ class Carousel(SphinxDirective):
             main_div.append(nodes.CarouselControlNode(top=buttons_on_top, shadow=shadows))
 
         return [main_div]
-
-
-class FigureCarousel(Figure):
-    """Standard `..figure::` directive with additional options."""
-
-    option_spec = Figure.option_spec.copy()
-    option_spec["no_title"] = flag
-
-    def run(self) -> List[Element]:
-        """Main method."""
-        if "no_title" in self.options and self.content:
-            self.content.insert(0, "Fake Title", *self.content.items[0])
-            self.content.insert(1, "", *self.content.items[0])
-        ret: List[figure] = super().run()  # noqa
-        if "no_title" in self.options and self.content:
-            figure_node = ret[0]
-            caption_node = figure_node.next_node(caption, siblings=False, ascend=False, descend=True)
-            figure_node.remove(caption_node)
-        return ret
